***************************************
Contributing to sphinxcontrib-towncrier
***************************************


.. attention::

   sphinxcontrib-towncrier project exists solely to allow embedding the
   unreleased changelog fragments that are prepared for the Towncrier
   tool into Sphinx-based docs sites.
   At the moment we don't accept any contributions, nor feature
   requests that are unrelated to this goal.

   But if you want to contribute a bug fix or send a pull-request
   improving our CI, testing and packaging, we will gladly review it.


In order to contribute, you'll need to:

  1. Fork the repository.

  2. Create a branch, push your changes there.

  3. Send it to us as a PR.

  4. Iterate on your PR, incorporating the requested improvements
     and participating in the discussions.
